2024-07-20 Version: 2.1.8
- Update API CreateEndpointGroup: add param EndpointProtocolVersion.
- Update API CreateEndpointGroups: update param EndpointGroupConfigurations.
- Update API CreateListener: update param EndpointGroupConfigurations.
- Update API DescribeEndpointGroup: update response param.
- Update API ListEndpointGroupIpAddressCidrBlocks: add param AcceleratorId.
- Update API ListEndpointGroups: update response param.
- Update API UpdateEndpointGroup: add param EndpointProtocolVersion.
- Update API UpdateEndpointGroups: update param EndpointGroupConfigurations.


2024-04-22 Version: 2.1.7
- Update API CreateEndpointGroups: update param EndpointGroupConfigurations.
- Update API CreateEndpointGroups: update param EndpointGroupConfigurations.
- Update API CreateEndpointGroups: update param EndpointGroupConfigurations.
- Update API CreateForwardingRules: update param ForwardingRules.
- Update API CreateForwardingRules: update param ForwardingRules.
- Update API CreateListener: add param HttpVersion.
- Update API DescribeListener: update response param.
- Update API ListAvailableAccelerateAreas: update response param.
- Update API ListListeners: update response param.
- Update API UpdateListener: add param HttpVersion.


2024-03-28 Version: 2.1.6
- Update API CreateListener: add param HttpVersion.
- Update API DescribeListener: update response param.
- Update API ListAvailableAccelerateAreas: update response param.
- Update API ListListeners: update response param.
- Update API UpdateListener: add param HttpVersion.


2024-03-28 Version: 2.1.6
- Update API CreateListener: add param HttpVersion.
- Update API DescribeListener: update response param.
- Update API ListAvailableAccelerateAreas: update response param.
- Update API ListListeners: update response param.
- Update API UpdateListener: add param HttpVersion.


2023-12-25 Version: 2.1.5
- Generated python 2019-11-20 for Ga.

2023-11-23 Version: 2.1.4
- Generated python 2019-11-20 for Ga.

2023-11-06 Version: 2.1.3
- Generated python 2019-11-20 for Ga.

2023-11-06 Version: 2.1.3
- Generated python 2019-11-20 for Ga.

2023-10-27 Version: 2.1.2
- Generated python 2019-11-20 for Ga.

2023-10-12 Version: 2.1.1
- Generated python 2019-11-20 for Ga.

2023-09-14 Version: 2.1.0
- Generated python 2019-11-20 for Ga.

2023-09-05 Version: 2.0.0
- Generated python 2019-11-20 for Ga.

2023-07-10 Version: 1.0.23
- Update region api.

2023-06-28 Version: 1.0.22
- Update EndPointGroup api.

2023-04-20 Version: 1.0.21
- Add resource tag for ga.

2023-04-06 Version: 1.0.20
- Add cross border status for Ga.

2023-01-12 Version: 1.0.19
- Add PostPay Basic Ga.

2022-12-09 Version: 1.0.18
- Update sdk.

2022-12-08 Version: 1.0.17
- Update sdk.

2022-12-06 Version: 1.0.16
- Tags for endpoint groups.

2022-11-15 Version: 1.0.15
- Update ReplaceBandwidthPackage Api.

2022-10-29 Version: 1.0.14
- Update Basic Ga Api.

2022-07-19 Version: 1.0.13
- Update Create Basic Ipset Api.

2022-05-24 Version: 1.0.12
- Add Bandwidthpackage auto renewal Api.

2022-04-19 Version: 1.0.11
- Update Application Monitor Api.

2022-04-07 Version: 1.0.10
- Add Anycast Api.
- Add 7 laryer forward rule.

2022-01-06 Version: 1.0.9
- Add Application Monitor Api.

2021-12-20 Version: 1.0.8
- Update createBasicAccelerator Api.
- Add UpdateAcceleratorAutoRenewAttribute Api.
- Add DescribeAcceleratorAutoRenewAttribute Api.

2021-11-30 Version: 1.0.7
- Update createBasicAccelerator Api.
- Add UpdateAcceleratorAutoRenewAttribute Api.
- Add DescribeAcceleratorAutoRenewAttribute Api.

2021-11-24 Version: 1.0.6
- Update createAccelerator Api.

2021-10-26 Version: 1.0.5
- Import config from trial global accelerator.

2021-09-17 Version: 1.0.4
- Remove some nouse parameter from api for multi certifications on listener.
- Add query param for multi certs list interface.

2021-08-09 Version: 1.0.3
- Supported api for multi certifications on listener.

2021-06-03 Version: 1.0.2
- Generated python 2019-11-20 for Ga.

2021-01-27 Version: 1.0.1
- AMP Version Change.

2021-01-27 Version: 1.0.0
- Generated python 2019-11-20 for Ga.

